
# =====================================================================================================================
# **NOTICE**
# THIS IS A GENERATED FILE USING THE SOURCE FILE:
#  crab\utilities\java\seeq-utilities\src\main\java\com\seeq\utilities\SeeqNames.java
# =====================================================================================================================

class SeeqNames:
    class Logging:
        class RemoteAgents:
            m_d_c_filename_key = 'agentlogfilename'
        
        class Appserver:
            m_d_c_filename_key = 'logfilename'
            default_file = 'appserver'
            startup_file = 'appserver-startup'
            upgrade_file = 'appserver-upgrade'
            async_upgrade_file = 'appserver-async-upgrade'
            licensing_file = 'appserver-licensing'
            requests = 'appserver-requests'
            request_monitors = 'appserver-requestmonitors'
            units = 'appserver-units'
            users = 'appserver-users'
            class IntervalAnalysis:
                fetch_critic = 'appserver-intervalanalysis-fetchcritic'
            
        
    
    class LocalDatasources:
        class Monitors:
            datasource_class = 'Monitors'
            datasource_id = 'monitors'
            datasource_name = 'Seeq Monitors'
        
        class Authentication:
            datasource_class = 'Auth'
            datasource_id = 'Seeq'
            datasource_name = 'Seeq'
        
        class FileSignalStorage:
            datasource_class = 'Seeq - Signal Datasource'
            datasource_id = 'Signal Datasource'
            datasource_name = 'Seeq Signal Datasource'
        
        class FileSignalCache:
            datasource_class = 'Seeq - FileSignal'
            datasource_id = 'default'
            datasource_name = 'Seeq Cache'
        
        class Timescale:
            datasource_class = 'Timescale'
            datasource_id = 'default'
            datasource_name = 'Seeq Database'
        
        class Datafile:
            datasource_class = 'Imported CSV Files'
            datasource_id = 'Imported CSV Files'
            datasource_name = 'Imported CSV Files'
        
        class Cassandra:
            datasource_class = 'cassandraV2'
            datasource_id = 'default'
            datasource_name = 'Seeq Database'
        
    
    class SwaggerApiNames:
        agents = 'Agents'
        ancillaries = 'Ancillaries'
        audit = 'Audit'
        auth = 'Auth'
        assets = 'Assets'
        folders = 'Folders'
        networks = 'Networks'
        items = 'Items'
        reports = 'Reports'
        jobs = 'Jobs'
        logs = 'Logs'
        trees = 'Trees'
        sample_series = 'SampleSeries'
        signals = 'Signals'
        capsules = 'Capsules'
        conditions = 'Conditions'
        metrics = 'Metrics'
        formulas = 'Formulas'
        functions = 'Functions'
        requests = 'Requests'
        tables = 'Tables'
        workbooks = 'Workbooks'
        worksheets = 'Worksheets'
        export = 'Export'
        annotations = 'Annotations'
        datasources = 'Datasources'
        datafiles = 'Datafiles'
        users = 'Users'
        user_groups = 'UserGroups'
        access_keys = 'AccessKeys'
        data_consumption = 'DataConsumption'
        scalars = 'Scalars'
        subscriptions = 'Subscriptions'
        system = 'System'
        import_ = 'Import'
        monitors = 'Monitors'
        projects = 'Projects'
        content = 'Content'
    
    class Channels:
        agents_status = 'agents-status'
        broadcast = 'broadcast'
        live_screenshot = 'live-screenshot'
        async_response = 'async-response'
        requests_progress = 'requests-progress'
        workbook_channel = 'workbook'
        workstep_channel = 'workstep'
        report_update_channel = 'report-update'
    
    class API:
        ace = '/ace'
        agents = '/agents'
        audit = '/audit'
        auth = '/auth'
        ancillaries = '/ancillaries'
        assets = '/assets'
        folders = '/folders'
        networks = '/networks'
        items = '/items'
        reports = '/reports'
        jobs = '/jobs'
        logs = '/logs'
        batch = '/batch'
        trees = '/trees'
        asset_trees = '/trees/assets'
        sample_series = '/sample-series'
        signals = '/signals'
        samples = '/samples'
        plot_samples = '/plot-samples'
        capsules = '/capsules'
        conditions = '/conditions'
        metrics = '/metrics'
        thresholds = '/thresholds'
        formulas = '/formulas'
        docs = '/docs'
        functions = '/functions'
        scalars = '/scalars'
        properties = '/properties'
        requests = '/requests'
        tables = '/tables'
        workbooks = '/workbooks'
        worksheets = '/worksheets'
        worksteps = '/worksteps'
        export = '/export'
        annotations = '/annotations'
        datasources = '/datasources'
        datafiles = '/datafiles'
        users = '/users'
        user_groups = '/usergroups'
        access_keys = '/accesskeys'
        o_data = '/odata.svc'
        system = '/system'
        import_ = '/import'
        status = '/status'
        screenshots = '/screenshots'
        subscriptions = '/subscriptions'
        monitors = '/system/monitors'
        configuration = '/system/configuration'
        projects = '/projects'
        content = '/content'
        date_ranges = '/date-ranges'
        class ExternalToolLinkType:
            window = 'window'
            tab = 'tab'
            none = 'none'
        
        class PropertyIds:
            authentication_session_id = 'com.seeq.authenticationsessionid'
            interactive_session_id = 'com.seeq.interactivesessionid'
            csrf_token = 'com.seeq.csrftoken'
            request_information = 'com.seeq.requestinformation'
        
        class Cookies:
            auth = 'sq-auth'
            csrf = 'sq-csrf'
        
        class QueryParams:
            request_id = 'requestId'
        
        class Headers:
            async_ = 'x-sq-async'
            auth = 'x-sq-auth'
            csrf = 'x-sq-csrf'
            forwarded_for = 'x-forwarded-for'
            interactive_session_id = 'Session-Id'
            request_id = 'x-sq-request-id'
            request_origin = 'x-sq-origin'
            server = 'Server'
            server_meters = 'Server-Meters'
            server_timing = 'Server-Timing'
            expect = 'Expect'
            date_range_start = 'x-sq-daterange-start'
            date_range_end = 'x-sq-daterange-end'
        
    
    class UnitTest:
        timestamp1 = '1990-03-07T09:58:20.888888Z'
        timestamp2 = '1990-04-08T10:59:21.999999Z'
        non_existent_guid = '1CB64296-FC3E-4221-9A7F-947A0AB99807'
    
    class Edges:
        owns = 'owns'
        contains = 'contains'
        member_of = 'member of'
        interested_in = 'interested in'
        replies_to = 'replies to'
        recently_accessed = 'recently accessed'
        has_worksheet = 'has worksheet'
        has_workstep = 'has workstep'
        current_workstep = 'current workstep'
        cached_by = 'cached by'
        cache_validity = 'cache validity'
        has_parameter = 'has parameter'
        has_ancillary = 'has ancillary'
        associated_to = 'associated to'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        access_for = 'access for'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        has_ace = 'has access control entry'
        has_pinned = 'has pinned'
        measuring = 'measuring'
        has_aggregation_signal = 'has aggregation signal'
        has_aggregation_formula_function = 'has aggregation formula function'
        bounded_by = 'bounded by'
        has_threshold = 'has threshold'
        has_condition_threshold = 'has condition threshold'
        renders = 'renders'
        source_worksheet = 'source worksheet'
        source_workstep = 'source workstep'
        has_date_range = 'has date range'
        has_condition = 'has condition'
        has_content = 'has content'
    
    class Types:
        asset = 'Asset'
        access_control_entry = 'AccessControlEntry'
        stored_signal = 'StoredSignal'
        caching_signal = 'CachingSignal'
        datasource = 'Datasource'
        table_datasource = 'TableDatasource'
        datafile = 'Datafile'
        calculated_signal = 'CalculatedSignal'
        signal = 'Signal'
        tree_definition = 'TreeDefinition'
        ancillary = 'Ancillary'
        identity = 'Identity'
        user = 'User'
        user_group = 'UserGroup'
        access_key = 'AccessKey'
        system_state = 'SystemState'
        export = 'Export'
        project_link = 'ProjectLink'
        external_tool = 'ExternalTool'
        base_annotation = 'BaseAnnotation'
        annotation = 'Annotation'
        report = 'Report'
        journal = 'Journal'
        reply = 'Reply'
        condition = 'Condition'
        capsule = 'Capsule'
        stored_condition = 'StoredCondition'
        caching_condition = 'CachingCondition'
        calculated_condition = 'CalculatedCondition'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        marker_series = 'MarkerSeries'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        stored_marker_series = 'StoredMarkerSeries'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        calculated_marker_series = 'CalculatedMarkerSeries'
        calculated_scalar = 'CalculatedScalar'
        formula_function = 'FormulaFunction'
        chart = 'Chart'
        threshold_metric = 'ThresholdMetric'
        folder = 'Folder'
        project = 'Project'
        content = 'Content'
        date_range = 'DateRange'
        workbook = 'Workbook'
        worksheet = 'Worksheet'
        workstep = 'Workstep'
        item = 'Item'
        item_with_owner = 'ItemWithOwner'
        type_definition = 'TypeDefinition'
    
    class TopicDocumentAttributes:
        data_seeq_content = 'data-seeq-content'
        data_seeq_content_pending = 'data-seeq-content-pending'
    
    class ActivityProperties:
        interval = 'Interval'
        category_datasource_read = 'Datasource Read'
    
    class CapsuleProperties:
        start = 'Start'
        end = 'End'
        duration = 'Duration'
        middle = 'Middle'
        count = 'Count'
        value = 'Value'
        unit = 'Unit'
        distance = 'Distance'
        similarity = 'Similarity'
        standard_deviation = 'Standard Deviation'
        sample_period = 'Sample Period'
        reference_capsule = 'Reference Capsule'
    
    class Properties:
        guid = 'GUID'
        name = 'Name'
        id = 'ID'
        description = 'Description'
        unsearchable = 'Unsearchable'
        archived = 'Archived'
        sync_token = 'Sync Token'
        number_format = 'Number Format'
        source_number_format = 'Source Number Format'
        scoped_to = 'Scoped To'
        import_item_type = 'Import Item Type'
        filename = 'Filename'
        name_row = 'Name Row'
        name_prefix = 'Name Prefix'
        name_suffix = 'Name Suffix'
        condition_name = 'Condition Name'
        first_data_row = 'First Data Row'
        description_row = 'Description Row'
        interpolation_method_row = 'Interpolation Method Row'
        maximum_interpolation_row = 'Maximum Interpolation Row'
        value_uom_row = 'Value Unit of Measure Row'
        field_delimiter = 'Field Delimiter'
        day_first_default = 'Day First Default'
        key_column_name = 'Key Column Name'
        key_column_index = 'Key Column Index'
        end_column_name = 'End Column Name'
        end_column_index = 'End Column Index'
        key_format = 'Key Format'
        time_zone = 'Time Zone'
        value_column_names = 'Value Column Names'
        value_column_indices = 'Value Column Indices'
        append = 'Append'
        validation_mode = 'Validation Mode'
        lenient_daylight_savings = 'Lenient Daylight Savings'
        datasource_class = 'Datasource Class'
        datasource_name = 'Datasource Name'
        datasource_id = 'Datasource ID'
        data_id = 'Data ID'
        data_version_check = 'Data Version Check'
        stored_in_seeq = 'Stored In Seeq'
        supports_string_signals = 'Supports String Signals'
        connection_request_timeout = 'Connection Request Timeout'
        windows_auth_mode = 'Windows Auth Mode'
        ldap_auth_mode = 'LDAP Auth Mode'
        username_password_compatible = 'Username/Password Compatible'
        username_human_readable = 'Username Human Readable'
        expect_duplicates_during_indexing = 'Expect Duplicates During Indexing'
        referenced_datasource_id = 'Referenced Datasource ID'
        referenced_datasource_class = 'Referenced Datasource Class'
        additional_groups_to_sync = 'Additional Groups To Sync'
        asset_progress = 'Asset Progress'
        asset_count = 'Asset Count'
        signal_progress = 'Signal Progress'
        signal_count = 'Signal Count'
        condition_progress = 'Condition Progress'
        condition_count = 'Condition Count'
        scalar_progress = 'Scalar Progress'
        scalar_count = 'Scalar Count'
        relationship_progress = 'Relationship Progress'
        relationship_count = 'Relationship Count'
        user_group_progress = 'UserGroup Progress'
        user_group_count = 'UserGroups Count'
        interpolation_method = 'Interpolation Method'
        source_maximum_interpolation = 'Source Maximum Interpolation'
        override_maximum_interpolation = 'Override Maximum Interpolation'
        maximum_interpolation = 'Maximum Interpolation'
        key_uom = 'Key Unit Of Measure'
        value_uom = 'Value Unit Of Measure'
        source_value_uom = 'Source Value Unit Of Measure'
        maximum_duration = 'Maximum Duration'
        cache_enabled = 'Cache Enabled'
        uncertainty_override = 'Uncertainty Override'
        metadata_properties = 'Metadata Properties'
        last_key_written = 'Last Key Written'
        request_interval_clamp = 'Request Interval Clamp'
        uom = 'Unit Of Measure'
        formula = 'Formula'
        swap_source_id = 'Swap Source ID'
        swap_key = 'Swap Key'
        cache_value = 'CacheValue'
        formula_parameters = 'FormulaParameters'
        aggregation_function = 'AggregationFunction'
        duration = 'Duration'
        period = 'Period'
        measured_item_maximum_duration = 'MeasuredItemMaximumDuration'
        bounding_condition_maximum_duration = 'BoundingConditionMaximumDuration'
        is_generated = 'Is Generated'
        export_data = 'Export Data'
        is_capsule_view = 'Is Capsule View'
        is_export_capsule_table = 'Is Export Capsule Table'
        is_autoupdate_time_range = 'Is Autoupdate Time Range'
        grid_size = 'Grid Size'
        user_email = 'User Email'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        auth_datasource_class = 'Auth Datasource Class'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        auth_datasource_id = 'Auth Datasource Id'
        username = 'Username'
        first_name = 'First Name'
        last_name = 'Last Name'
        password_hash = 'Password Hash'
        password_hash_method = 'Password Hash Method'
        password_set_date = 'Password Set Date'
        last_login_at = 'Last Login At'
        session_duration = 'Session Duration'
        enabled = 'Enabled'
        admin = 'Admin'
        workbench = 'Workbench'
        data = 'Data'
        created_at = 'Created At'
        updated_at = 'Updated At'
        order = 'Order'
        document = 'Document'
        plain_text_document = 'Plain Text Document'
        discoverable = 'Discoverable'
        published_at = 'Published At'
        source_security_string = 'Source Security String'
        security_string = 'Security String'
        permissions_from_datasource = 'Permissions From Datasource'
        permission_inheritance_disabled = 'Permission Inheritance Disabled'
        first_admin_created = 'First Admin Created'
        u_i_config = 'UIConfig'
        dirty_cache = 'Dirty Cache'
        height = 'Height'
        width = 'Width'
        scale = 'Scale'
        timezone = 'Timezone'
        selector = 'Selector'
        last_screenshot_duration = 'Last Screenshot Duration'
        average_screenshot_duration = 'Average Screenshot Duration'
        cron_schedule = 'Cron Schedule'
        background = 'Background'
        condition_formula_now = 'Condition Formula Now'
        icon_class = 'Icon Class'
        target_url = 'Target URL'
        link_type = 'Link Type'
        window_details = 'Window Details'
        reuse_window = 'Reuse Window'
        sort_key = 'Sort Key'
    



